<?php

namespace Drupal\crisis_mode\Commands;

use Drupal\Component\Plugin\PluginManagerInterface;
use Drush\Commands\DrushCommands;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\block\Entity\Block;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Drush commands for the custom_module module.
 */
class CrisisModeCommands extends DrushCommands {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The Plugin Manager.
   *
   * @var \Drupal\Component\Plugin\PluginManagerInterface
   */
  protected $blockPluginManager;

  /**
   * Class constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Component\Plugin\PluginManagerInterface $block_plugin_manager
   *   The block plugin manager.
   */
  public function __construct(ConfigFactoryInterface $config_factory, PluginManagerInterface $block_plugin_manager) {
    $this->configFactory = $config_factory;
    $this->blockPluginManager = $block_plugin_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('plugin.manager.block')
    );
  }

  /**
   * Enable or disable the crisis situation.
   *
   * @param string $flag
   *   'on' to enable crisis mode, 'off' to disable. Default is 'on'.
   *
   * @command crisis-mode
   * @aliases crisis
   * @usage crisis-mode:on
   *   Enable crisis mode.
   * @usage crisis-mode:off
   *   Disable crisis mode.
   */
  public function crisisModeCommand(string $flag = 'on') {
    if ($flag == 'on' || $flag == 'off') {
      $this->io()->comment("Setting crisis situation to '{$flag}' ...");
      $this->crisisModeSwitch($flag);
    }
    else {
      $this->io()->error("Invalid argument. Use 'on' or 'off'.");
    }
  }

  /**
   * Toggling the block visibility.
   */
  public function crisisModeSwitch($flag = 'on') {
    $config = $this->configFactory->getEditable('crisis_mode.settings');
    $block = Block::load('crisismodeblock');

    if ($flag == 'on') {
      $config->set('crisis_mode_active', 1);
      $config->save();
      $block->enable();
    }
    else {
      $config->set('crisis_mode_active', 0);
      $config->save();
      $block->disable();
    }

    $this->io()->success("Crisis situation block '{$flag}'!");
    $block->save();
  }

}
